@@ -286,7 +286,8 @@ def Heatmap_Survey_group_difference(df,comparison_col_name,comparison_order,choi
 
     # get the total in 2 fields
     totals = temp.groupby(by = [category_col_name,comparison_col_name]).sum().reset_index()
-    totals.drop(choice_col_name,axis=1,inplace=True)
+    if choice_col_name in list(totals.columns):
+        totals.drop(choice_col_name,axis=1,inplace=True)
     
     # join the totals onto the groups
     grp = pd.merge(left = grp,right = totals, on=[category_col_name,comparison_col_name],suffixes=('_level','_levelgroup'))
@@ -298,8 +299,8 @@ def Heatmap_Survey_group_difference(df,comparison_col_name,comparison_order,choi
     grp_cross_ethnicity = pd.merge(left=grp,right=grp,on=[category_col_name,choice_col_name])
 
 
-    grp_cross_ethnicity = grp_cross_ethnicity[(grp_cross_ethnicity[comparison_col_name+'_x'] == 'C') & (grp_cross_ethnicity[comparison_col_name+'_y'] == 'S')]
-    grp_cross_ethnicity = grp_cross_ethnicity[(grp_cross_ethnicity['Count_level_x'] > minimum_size) & (grp_cross_ethnicity['Count_level_y'] > minimum_size)]
+    grp_cross_ethnicity = grp_cross_ethnicity[(grp_cross_ethnicity[comparison_col_name+'_x'] == comparison_order[0]) & (grp_cross_ethnicity[comparison_col_name+'_y'] == comparison_order[0])]
+    grp_cross_ethnicity = grp_cross_ethnicity[(grp_cross_ethnicity['choice_level_x'] > minimum_size) & (grp_cross_ethnicity['choice_level_y'] > minimum_size)]
     grp_cross_ethnicity['ScaledProp'] = grp_cross_ethnicity[['pct in group_y','pct in group_x']].apply(lambda x: round(x[0]*100/(x[0]+x[1]),2),axis=1)
 
     # remove rows smaller than 10
@@ -356,8 +357,9 @@ def Heatmap_Survey_group_difference(df,comparison_col_name,comparison_order,choi
                 print('{0} and {1}: \npvalue = {2} \n{3}count_{4}count = {5}_{6} \n{3}true_{4}true = {7}_{8} \nproportions = {9}:{10} \nScaled Proportions = {11}:{12} \nd-prime significant: {13}\n\n'.format(xlab,ylab,pvalue,comparison_order[0],comparison_order[1],cohort1_len,cohort2_len,pos1_len,pos2_len,prop1,prop2,scaledprop1,scaledprop2,(scaledprop1 >= 0.6) or (scaledprop2 >= 0.6)))
 
             if annotate_pvalue_significance:
-                if pvalue <= significance_level:
-                    sns.scatterplot(x=[xtiks[ix] + (xtiks[1]-xtiks[0])/4],y=[ytiks[iy]],s=200,marker="*",color='black',ax=ax)
+                if (pos1_len > minimum_size) and (pos2_len > minimum_size):
+                    if pvalue <= significance_level:
+                        sns.scatterplot(x=[xtiks[ix] + (xtiks[1]-xtiks[0])/4],y=[ytiks[iy]],s=200,marker="*",color='black',ax=ax)
 
             if annotate_dprime:
                 if (pos1_len > minimum_size) and (pos2_len > minimum_size):
